//==========================================================================
// File: rdebug.c
// Description: An implementation of rdebug routing
// Author: Pat Morin
// Created: Wed Jan 20 20:13:58 EST 1999
//==========================================================================
#include "rdebug.h"

#include <LEDA/window.h>

//==========================================================================
// Draw the graph G with vertex positions defined by pos, and draw the path
// P that is supposed to go from u to v (but possibly doesn't).
//========================================================================
void display_path(char *title, graph &G, node_array<point> &pos, list<node> P,
		  node u, node v)
{
  // open the window
  window W(600+20, 600+20, title);  
  W.button("dismiss",1);
  W.open(window::center,window::center);
  W.init(-.1, 1.2, -.1);

  // draw the graph in black
  W.clear();
  edge e;
  forall_edges (e, G) {
    W.draw_segment(pos[G.source(e)], pos[G.target(e)], black);
  }

  // draw the path in red
  list_item prev = P.first();
  list_item next = P.succ(prev);
  while (next != nil) {
    W.draw_segment(pos[P.inf(prev)], pos[P.inf(next)], red);
    prev = next;
    next = P.succ(next);
  }
  
  // draw the source in green and the destination in blue
  W.draw_node(pos[u], green);
  W.draw_node(pos[v], blue);

  // wait for the user to continue
  while (1 < 2) { 
    double x, y;
    int k = W.read_mouse(x, y);
    if (k==1) break;
  }

}
