//==========================================================================
// File: voronoi.h
// Description: An implementation of Voronoi routing
// Author: Pat Morin
// Created: Sun Mar 28 21:45:10 EST 1999
//==========================================================================
#ifndef __VORONOI_H
#define __VORONOI_H

#include <LEDA/graph.h>
#include <LEDA/point.h>
#include <LEDA/node_array.h>
#include <LEDA/node_matrix.h>

//==========================================================================
// Compute the Voronoi path from s to t and store this path in P
// Complexity: O(n)
// Precondition: G is a Delaunay triangulation
//==========================================================================
void VORONOI_PATH(graph &G, node_array<point> &pos, 
		  node s, node t, list<node> &P);


//==========================================================================
// Compute the parallel Voronoi path from s to t and store this path
// in P
// Complexity: O(n)
// Precondition: G is a Delaunay triangulation
//==========================================================================
void PARALLEL_VORONOI_PATH(graph &G, node_array<point> &pos, 
		  node s, node t, list<node> &P);


//==========================================================================
// Find the Voronoi routing path between all pairs of vertices in G.
// Complexity: O(n^3)
// Precondition: G is a Delaunay triangulation
//========================================================================
void VORONOI_TEST(graph &G, node_array<point>& pos);

#endif __VORONOI_H



